@@ -377,6 +377,35 @@ auto transform_parallelly_n_threads(std::size_t n, F f, const ContainerIn& xs)
         thread_results);
 }
 
+// API search type: transform_convert_parallelly : ((a -> b), [a]) -> [b]
+// fwd bind count: 1
+// transform_convert_parallelly((*2), [1, 3, 4]) == [2, 6, 8]
+// Same as transform_convert, but can utilize multiple CPUs by using std::launch::async.
+// Only makes sense if one run of the provided function
+// takes enough time to justify the synchronization overhead.
+// One thread per container element is spawned.
+template <typename ContainerOut, typename F, typename ContainerIn>
+ContainerOut transform_convert_parallelly(F f, const ContainerIn& xs)
+{
+    using X = typename ContainerIn::value_type;
+    internal::trigger_static_asserts<internal::unary_function_tag, F, X>();
+    auto handles = transform([&f](const X& x) {
+        return std::async(std::launch::async, [&x, &f]() {
+            return internal::invoke(f, x);
+        });
+    },
+        xs);
+
+    internal::trigger_static_asserts<internal::unary_function_tag, F, typename ContainerIn::value_type>();
+    ContainerOut ys;
+    internal::prepare_container(ys, size_of_cont(xs));
+    auto it = internal::get_back_inserter<ContainerOut>(ys);
+    for (auto& handle : handles) {
+        *it = handle.get();
+    }
+    return ys;
+}
+
 // API search type: reduce_parallelly : (((a, a) -> a), a, [a]) -> a
 // fwd bind count: 2
 // reduce_parallelly((+), 0, [1, 2, 3]) == (0+1+2+3) == 6
